@@ -94,7 +94,8 @@ static const char *settings_str[] = {
 				"ssp",
 				"br/edr",
 				"hs",
-				"le" ,
+				"le",
+				"advertising",
 };
 
 static void print_settings(uint32_t settings)
@@ -552,10 +553,8 @@ static void user_confirm(uint16_t index, uint16_t len, const void *param,
 	}
 
 	rsp_len = strlen(rsp);
-	if (rsp[rsp_len - 1] == '\n') {
+	if (rsp[rsp_len - 1] == '\n')
 		rsp[rsp_len - 1] = '\0';
-		rsp_len--;
-	}
 
 	if (rsp[0] == 'y' || rsp[0] == 'Y')
 		mgmt_confirm_reply(mgmt, index, &ev->addr.bdaddr);
@@ -899,7 +898,7 @@ static void cmd_discov(struct mgmt *mgmt, uint16_t index, int argc,
 	struct mgmt_cp_set_discoverable cp;
 
 	if (argc < 2) {
-		printf("Usage: btmgmt %s <yes/no> [timeout]\n", argv[0]);
+		printf("Usage: btmgmt %s <yes/no/limited> [timeout]\n", argv[0]);
 		exit(EXIT_FAILURE);
 	}
 
@@ -909,6 +908,8 @@ static void cmd_discov(struct mgmt *mgmt, uint16_t index, int argc,
 		cp.val = 1;
 	else if (strcasecmp(argv[1], "off") == 0)
 		cp.val = 0;
+	else if (strcasecmp(argv[1], "limited") == 0)
+		cp.val = 2;
 	else
 		cp.val = atoi(argv[1]);
 
@@ -964,6 +965,17 @@ static void cmd_le(struct mgmt *mgmt, uint16_t index, int argc, char **argv)
 	cmd_setting(mgmt, index, MGMT_OP_SET_LE, argc, argv);
 }
 
+static void cmd_advertising(struct mgmt *mgmt, uint16_t index, int argc,
+								char **argv)
+{
+	cmd_setting(mgmt, index, MGMT_OP_SET_ADVERTISING, argc, argv);
+}
+
+static void cmd_bredr(struct mgmt *mgmt, uint16_t index, int argc, char **argv)
+{
+	cmd_setting(mgmt, index, MGMT_OP_SET_BREDR, argc, argv);
+}
+
 static void class_rsp(uint16_t op, uint16_t id, uint8_t status, uint16_t len,
 							const void *param)
 {
@@ -1757,7 +1769,47 @@ done:
 
 	if (mgmt_send(mgmt, MGMT_OP_SET_DEVICE_ID, index, sizeof(cp), &cp,
 						did_rsp, NULL, NULL) == 0) {
-		fprintf(stderr, "Unable to send set_dev_class cmd\n");
+		fprintf(stderr, "Unable to send set_device_id cmd\n");
+		exit(EXIT_FAILURE);
+	}
+}
+
+static void static_addr_rsp(uint8_t status, uint16_t len, const void *param,
+							void *user_data)
+{
+	if (status != 0)
+		fprintf(stderr, "Set static address failed "
+						"with status 0x%02x (%s)\n",
+						status, mgmt_errstr(status));
+	else
+		printf("Static address successfully set\n");
+
+	g_main_loop_quit(event_loop);
+}
+
+static void static_addr_usage(void)
+{
+	printf("Usage: btmgmt static-addr <address>\n");
+}
+
+static void cmd_static_addr(struct mgmt *mgmt, uint16_t index,
+							int argc, char **argv)
+{
+	struct mgmt_cp_set_static_address cp;
+
+	if (argc < 2) {
+		static_addr_usage();
+		exit(EXIT_FAILURE);
+	}
+
+	if (index == MGMT_INDEX_NONE)
+		index = 0;
+
+	str2ba(argv[1], &cp.bdaddr);
+
+	if (mgmt_send(mgmt, MGMT_OP_SET_STATIC_ADDRESS, index, sizeof(cp), &cp,
+					static_addr_rsp, NULL, NULL) == 0) {
+		fprintf(stderr, "Unable to send set_static_address cmd\n");
 		exit(EXIT_FAILURE);
 	}
 }
@@ -1780,6 +1832,8 @@ static struct {
 	{ "ssp",	cmd_ssp,	"Toggle SSP mode"		},
 	{ "hs",		cmd_hs,		"Toggle HS Support"		},
 	{ "le",		cmd_le,		"Toggle LE Support"		},
+	{ "advertising",cmd_advertising,"Toggle LE advertising",	},
+	{ "bredr",      cmd_bredr,      "Toggle BR/EDR support",	},
 	{ "class",	cmd_class,	"Set device major/minor class"	},
 	{ "disconnect", cmd_disconnect, "Disconnect device"		},
 	{ "con",	cmd_con,	"List connections"		},
@@ -1795,6 +1849,7 @@ static struct {
 	{ "rm-uuid",	cmd_remove_uuid, "Remove UUID"			},
 	{ "clr-uuids",	cmd_clr_uuids,	"Clear UUIDs",			},
 	{ "did",	cmd_did,	"Set Device ID",		},
+	{ "static-addr",cmd_static_addr,"Set static address",		},
 	{ NULL, NULL, 0 }
 };
 
